@@ -14,4 +14,6 @@ class Container(AbstractDataType):
     name: str = None
 
     def __repr__(self):
-        return self.name
+        if self.name:
+            return f'{self.name}'
+        return f'{self.id}'
